@@ -715,6 +715,13 @@ class VirtualService(HttpClient, KempBaseObjectModel):
             }
 
     def save(self, update=False):
+        """ Send API request to add or update the VirtualService
+
+        For saving virtual, or sub virtual services to the LoadMaster.
+        When the service is a sub virtual service, it will also update the sub
+        virtual services 'real server' (weight, conns, etc.) parameters as well
+        :param update: If True, it will perform an update instead of create
+        """
         try:
             if not update:
                 if self._is_sub_vs:
@@ -753,6 +760,9 @@ class VirtualService(HttpClient, KempBaseObjectModel):
         else:
             raise KempTechApiException(get_error_msg(response))
 
+    def update(self):
+        self.save(update=True)
+
     def delete(self):
         response = self._get("/delvs", self._get_base_parameters())
         return send_response(response)
